@@ -6,6 +6,8 @@ use Mouse;
 use Elive;
 use base qw{Elive};
 
+__PACKAGE__->mk_classdata('element_class');
+
 use UNIVERSAL;
 
 =head1 NAME
@@ -39,9 +41,6 @@ sub stringify {
     #
     my $string = join(';', sort map {Elive::Util::string($_)} @$arr);
 
-##    use YAML; warn YAML::Dump({class => $class, data => $arr});
-##    warn "string: $string";
-
     return $string;
 }
 
@@ -55,4 +54,27 @@ sub new {
     return bless($_[1] || [], $_[0]);
 }
 
+=head2 add 
+
+    $group->members->add('111111', '222222');
+
+Add elements to an array.
+
+=cut
+
+sub add {
+    my $self = shift;
+
+    my @elems = grep {defined} @_;
+
+    if (my $element_class = $self->element_class) {
+	foreach (@elems) {
+	    $_ = $element_class->new($_)
+		unless Scalar::Util::blessed($_);
+	}
+    }
+
+    push (@$self, @elems);
+}
+
 1;
